<?php
/**
*
* @package acp
* @version $Id: acp_troll.php 144 2008-06-23 22:23:04Z evil3 $
* @copyright (c) 2008 evil3
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

/**
* @package acp
*/
class acp_troll
{
	public $u_action;
	protected $new_config;

	public function main($id, $mode)
	{
		global $user;

		$user->add_lang('acp/troll');

		switch ($mode)
		{
			case 'main':
				$this->display_main();
			break;
			case 'config':
				$this->display_config();
			break;
		}
	}

	public function display_main()
	{
		global $user, $db, $template;
		global $phpbb_root_path, $phpEx;

		// page settings
		$this->page_title = $user->lang['ACP_TROLL'];
		$this->tpl_name = 'acp_troll';

		// form key
		$form_key = 'acp_troll';

		add_form_key($form_key);

		// request vars
		$trollsubmit	= request_var('trollsubmit', false);
		$untrollsubmit	= request_var('untrollsubmit', false);

		if (($trollsubmit || $untrollsubmit) && !check_form_key($form_key))
		{
			trigger_error($user->lang['FORM_INVALID'] . adm_back_link($this->u_action), E_USER_WARNING);
		}

		// Troll submitted?
		if ($trollsubmit)
		{
			$usernames = array_map('trim', explode("\n", utf8_normalize_nfc(request_var('troll', '', true))));

			foreach ($usernames as $username)
			{
				// skip empty users
				if ($username === '')
				{
					continue;
				}

				// Get troll user id
				$sql = 'SELECT user_id
					FROM ' . USERS_TABLE . '
					WHERE username_clean = \'' . $db->sql_escape(utf8_clean_string($username)) . '\'
						AND user_type = ' . USER_NORMAL;
				$result = $db->sql_query_limit($sql, 1);
				$user_id = $db->sql_fetchfield('user_id');
				$db->sql_freeresult($result);

				if ($user_id)
				{
					troll_mod::add_troll($user_id);
				}
			}

			trigger_error($user->lang['TROLL_UPDATE_SUCCESSFUL'] . adm_back_link($this->u_action));
		}
		else if ($untrollsubmit)
		{
			$user_id = request_var('untroll', array(0 => ''));

			if ($user_id)
			{
				troll_mod::delete_troll($user_id);

				trigger_error($user->lang['TROLL_UPDATE_SUCCESSFUL'] . adm_back_link($this->u_action));
			}
		}

		// select all trolls
		$sql = 'SELECT t.troll_id, u.user_id, u.username, u.username_clean
			FROM ' . TROLLS_TABLE . ' t, ' . USERS_TABLE . ' u
			WHERE u.user_id = t.user_id
			ORDER BY u.username_clean ASC';
		$result = $db->sql_query($sql);

		$troll_options = '';
		while ($row = $db->sql_fetchrow($result))
		{
			$troll_options .= '<option value="' . $row['troll_id'] . '">' . $row['username'] . '</option>';
		}
		$db->sql_freeresult($result);

		// template vars
		$template->assign_vars(array(
			'L_TITLE'				=> $this->page_title,
			'L_EXPLAIN'				=> $user->lang['ACP_TROLL_EXPLAIN'],
			'L_UNTROLL_TITLE'		=> $user->lang['ACP_TROLL_UNTROLL'],
			'L_UNTROLL_EXPLAIN'		=> $user->lang['ACP_TROLL_UNTROLL_EXPLAIN'],

			'TROLL_OPTIONS'			=> $troll_options,

			'U_ACTION'				=> $this->u_action,
			'U_FIND_USERNAME'		=> append_sid("{$phpbb_root_path}memberlist.$phpEx", 'mode=searchuser&amp;form=acp_troll&amp;field=troll'),
		));
	}

	public function display_config()
	{
		global $user, $template;
		global $config;

		// set new config
		$this->new_config = $config;

		// initialisation
		$error = $display_vars = array();

		// page settings
		$this->page_title = $user->lang['ACP_TROLL_CONFIG'];
		$this->tpl_name = 'acp_board';

		// form key
		$form_key = 'acp_troll_config';

		add_form_key($form_key);

		// request vars
		$cfg_array = (isset($_REQUEST['config'])) ? utf8_normalize_nfc(request_var('config', array('' => ''), true)) : $this->new_config;
		$submit = isset($_POST['submit']) ? true : false;

		// set our display vars
		$display_vars = array(
			'legend1'				=> 'TROLL_GENERAL',
			'troll_virus'			=> array('lang' => 'TROLL_VIRUS',				'validate' => 'bool',	'type' => 'radio:enabled_disabled', 'explain' => true),
			'troll_chance'			=> array('lang' => 'TROLL_CHANCE',				'validate' => 'int:2',	'type' => 'text:4:10', 'explain' => true, 'append' => ' ' . $user->lang['SECONDS']),

			'legend2'				=> 'TROLL_BOARD',
			'troll_post'			=> array('lang' => 'TROLL_POST',				'validate' => 'bool',	'type' => 'radio:enabled_disabled', 'explain' => true),
			'troll_pm'				=> array('lang' => 'TROLL_PM',					'validate' => 'bool',	'type' => 'radio:enabled_disabled', 'explain' => true),
			'troll_email'			=> array('lang' => 'TROLL_EMAIL',				'validate' => 'bool',	'type' => 'radio:enabled_disabled', 'explain' => true),
		);

		// We validate the complete config if whished
		validate_config_vars($display_vars, $cfg_array, $error);

		if ($submit && !check_form_key($form_key))
		{
			$error[] = $user->lang['FORM_INVALID'];
		}

		// Do not write values if there is an error
		if (sizeof($error))
		{
			$submit = false;
		}

		// We go through the display_vars to make sure no one is trying to set variables he/she is not allowed to...
		foreach ($display_vars as $config_name => $null)
		{
			if (!isset($cfg_array[$config_name]) || strpos($config_name, 'legend') !== false)
			{
				continue;
			}

			$this->new_config[$config_name] = $config_value = $cfg_array[$config_name];

			if ($submit)
			{
				set_config($config_name, $config_value);
			}
		}

		if ($submit)
		{
			add_log('admin', 'LOG_TROLL_CONFIG');

			trigger_error($user->lang['CONFIG_UPDATED'] . adm_back_link($this->u_action));
		}

		// Output relevant page
		foreach ($display_vars as $config_key => $vars)
		{
			if (!is_array($vars) && strpos($config_key, 'legend') === false)
			{
				continue;
			}

			if (strpos($config_key, 'legend') !== false)
			{
				$template->assign_block_vars('options', array(
					'S_LEGEND'		=> true,
					'LEGEND'		=> (isset($user->lang[$vars])) ? $user->lang[$vars] : $vars,
				));

				continue;
			}

			$type = explode(':', $vars['type']);

			$l_explain = '';
			if ($vars['explain'] && isset($vars['lang_explain']))
			{
				$l_explain = (isset($user->lang[$vars['lang_explain']])) ? $user->lang[$vars['lang_explain']] : $vars['lang_explain'];
			}
			else if ($vars['explain'])
			{
				$l_explain = (isset($user->lang[$vars['lang'] . '_EXPLAIN'])) ? $user->lang[$vars['lang'] . '_EXPLAIN'] : '';
			}

			$content = build_cfg_template($type, $config_key, $this->new_config, $config_key, $vars);

			if (empty($content))
			{
				continue;
			}

			$template->assign_block_vars('options', array(
				'KEY'			=> $config_key,
				'TITLE'			=> (isset($user->lang[$vars['lang']])) ? $user->lang[$vars['lang']] : $vars['lang'],
				'S_EXPLAIN'		=> $vars['explain'],
				'TITLE_EXPLAIN'	=> $l_explain,
				'CONTENT'		=> build_cfg_template($type, $config_key, $this->new_config, $config_key, $vars),

			));

			unset($display_vars[$config_key]);
		}

		// template vars
		$template->assign_vars(array(
			'L_TITLE'				=> $this->page_title,
			'L_TITLE_EXPLAIN'		=> $user->lang['ACP_TROLL_CONFIG_EXPLAIN'],

			'U_ACTION'				=> $this->u_action,
		));
	}

	public function display_manage()
	{

	}
}

?>