<?php
/**
*
* @package phpBB3
* @version $Id: functions_troll.php 144 2008-06-23 22:23:04Z evil3 $
* @copyright (c) 2008 evil3
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

/**
 * static class for troll mod functions
 */
class troll_mod
{
	/**
	 * called before doing anything (in hook)
	 */
	public static function common()
	{
		global $phpbb_root_path, $phpEx;

		include($phpbb_root_path . 'includes/constants_troll.' . $phpEx);
	}

	/**
	 * most of code taken from Troll MOD for phpBB2 by Kalipo
	 * this function is like google (evil)
	 */
	public static function process_troll()
	{
		global $user;
		global $phpbb_root_path, $phpEx, $config;

		// set a time limit of 2 minutes because of the sleeps
		@set_time_limit(120);

		// set troll cookie
		$user->set_cookie('t', md5('i am a troll ' . time()), time() + 31536000);

		// the chance check
		if (!$config['troll_chance'] || time() % (int) $config['troll_chance'] != 0)
		{
			return;
		}

		// do we have a specific troll action, then let it do its own work
		if ($troll_action_name = self::is_special())
		{
			return;
		}

		// include troll action base class
		include($phpbb_root_path . 'includes/troll/base.' . $phpEx);

		// obtain troll actions
		$troll_actions = self::obtain_troll_actions();

		// check if we have troll actions at all
		if (sizeof($troll_actions))
		{
			// use pseudo code for the actions for now
			$troll_action_name = $troll_actions[array_rand($troll_actions)];

			// check if the action exists
			// it's possible that one was deleted and now the caching still stores it
			if (!file_exists("{$phpbb_root_path}includes/troll/$troll_action_name.$phpEx"))
			{
				global $cache;
				$cache->destroy('_troll_actions');
				return;
			}

			// include our action and process it
			include("{$phpbb_root_path}includes/troll/$troll_action_name.$phpEx");
			$troll_action = new $troll_action_name();
			$troll_action->action();
		}
	}

	/**
	 * code for pre-submit_post
	 */
	public static function process_posting($mode, $forum_id, $topic_id, $post_id)
	{
		global $user;
		global $config, $phpbb_root_path, $phpEx;

		if (!$config['troll_post'] || !$config['troll_chance'] || !self::is_special())
		{
			return;
		}

		if ($mode == 'post' || $mode == 'reply' || $mode == 'edit')
		{
			$message = $user->lang['POST_STORED'];
			if ($topic_id)
			{
				$message .= '<br /><br />' . sprintf($user->lang['VIEW_MESSAGE'], '<a href="' . append_sid("{$phpbb_root_path}viewtopic.$phpEx", "f=$forum_id&amp;t=$topic_id" . ($post_id ? "&amp;p=$post_id" : '')) . '">', '</a>');
			}
			$message .= '<br /><br />' . sprintf($user->lang['RETURN_FORUM'], '<a href="' . append_sid("{$phpbb_root_path}viewforum.$phpEx", "f=$forum_id") . '">', '</a>');
			trigger_error($message);
		}
	}

	/**
	 * code for pre-submit_pm
	 */
	public static function process_pm()
	{
		global $user;
		global $config, $phpbb_root_path, $phpEx;

		if (!$config['troll_pm'] || !$config['troll_chance'] || !self::is_special())
		{
			return;
		}

		$message = $user->lang['MESSAGE_STORED'];
		$message .= '<br /><br />' . sprintf($user->lang['CLICK_RETURN_FOLDER'], '<a href="' . append_sid("{$phpbb_root_path}ucp.$phpEx", 'i=pm&amp;folder=outbox') . '">', '</a>', $user->lang['PM_OUTBOX']);
		trigger_error($message);
	}

	/**
	 * code for submitting emails
	 */
	public static function process_email($user_id, $forum_id, $topic_id)
	{
		global $user;
		global $config, $phpbb_root_path, $phpEx;

		if (!$config['troll_email'] || !$config['troll_chance'] || !self::is_special())
		{
			return;
		}

		$message = ($user_id) ? sprintf($user->lang['RETURN_INDEX'], '<a href="' . append_sid("{$phpbb_root_path}index.$phpEx") . '">', '</a>') : sprintf($user->lang['RETURN_TOPIC'],  '<a href="' . append_sid("{$phpbb_root_path}viewtopic.$phpEx", "f=$forum_id&amp;t=$topic_id") . '">', '</a>');
		trigger_error($user->lang['EMAIL_SENT'] . '<br /><br />' . $message);
	}

	/**
	 * check if the user is a troll
	 */
	public static function is_troll()
	{
		global $db, $user, $config;

		// if we're installing the MOD, don't run troll code
		if (defined('IN_INSTALL_TROLL'))
		{
			return false;
		}

		// do not treat founders as trolls
		if ($user->data['user_type'] == USER_FOUNDER)
		{
			// untroll founders
			if (isset($_COOKIE[$config['cookie_name'] . '_t']))
			{
				$user->set_cookie('t', '', time() - 31536000);
			}

			return false;
		}

		// bots can not be trolls
		if ($user->data['is_bot'])
		{
			return false;
		}

		$sql = 'SELECT user_id
			FROM ' . TROLLS_TABLE . '
			WHERE user_id = ' . (int) $user->data['user_id'];
		$result = $db->sql_query_limit($sql, 1);
		$is_troll = (bool) $db->sql_fetchfield('user_id');
		$db->sql_freeresult($result);

		if (!isset($_COOKIE[$config['cookie_name'] . '_t']) && !$is_troll)
		{
			// no troll cookie set and not in trolls table
			return false;
		}
		else if ($user->data['is_registered'] && !$is_troll && isset($_COOKIE[$config['cookie_name'] . '_t']))
		{
			if ($config['troll_virus'])
			{
				// troll virus enabled, add user to trolls table
				self::add_troll($user->data['user_id']);
				return true;
			}

			// user is logged in and not a troll, then remove cookie
			$user->set_cookie('t', '', time() - 31536000);
			return false;
		}

		return true;
	}

	/**
	 * add a troll to the trolls table
	 */
	public static function add_troll($user_id)
	{
		global $db;

		$sql = 'SELECT troll_id
			FROM ' . TROLLS_TABLE . '
			WHERE user_id = ' . (int) $user_id;
		$result = $db->sql_query_limit($sql, 1);
		$exists = (bool) $db->sql_fetchfield('troll_id');
		$db->sql_freeresult($result);

		if ($exists)
		{
			return false;
		}

		$sql = 'INSERT INTO ' . TROLLS_TABLE . ' ' . $db->sql_build_array('INSERT', array(
			'user_id'	=> (int) $user_id,
		));
		$db->sql_query($sql);

		return $db->sql_nextid();
	}

	/**
	 * delete a troll from the db
	 */
	public static function delete_troll($troll_id)
	{
		global $db;

		$sql_where = (is_array($troll_id)) ? $db->sql_in_set('troll_id', array_map('intval', $troll_id)) : 'troll_id = ' . (int) $troll_id;

		$sql = 'DELETE FROM ' . TROLLS_TABLE . '
			WHERE ' . $sql_where;
		$db->sql_query($sql);
	}

	/**
	 * Get a list of troll actions
	 */
	public static function obtain_troll_actions()
	{
		global $cache;
		global $phpbb_root_path, $phpEx;

		if (($troll_actions = $cache->get('_troll_actions')) === false)
		{
			$troll_actions = array();

			foreach (scandir($phpbb_root_path . 'includes/troll/') as $file)
			{
				if (preg_match('#^troll_(.+)\.' . preg_quote($phpEx, '#') . '$#', $file))
				{
					$troll_actions[] = substr($file, 0, -strlen($phpEx) - 1);
				}
			}

			$cache->put('_troll_actions', $troll_actions);
		}

		return $troll_actions;
	}

	/**
	 * check if we're on a special page
	 */
	public static function is_special()
	{
		global $phpEx;

		if (basename($_SERVER['SCRIPT_NAME']) === "posting.$phpEx" && isset($_POST['post']))
		{
			return true;
		}
		else if (basename($_SERVER['SCRIPT_NAME']) === "ucp.$phpEx" && isset($_POST['post']))
		{
			return true;
		}
		else if (basename($_SERVER['SCRIPT_NAME']) === "memberlist.$phpEx" && isset($_POST['submit']) && isset($_REQUEST['mode']) && (string) $_REQUEST['mode'] === 'email')
		{
			return true;
		}

		return false;
	}
}

?>